@@ -4,10 +4,10 @@ import numpy as np
 from numpy.lib.function_base import average
 import pygame as py
 from pygame import pixelcopy
-import pygame
 from pygame.transform import flip
 from pygame.draw import line
 from pygame.version import ver
+import math as mh
 
 ################################################## 1 蚁群算法路径规划 ###########################################
 
@@ -630,10 +630,7 @@ class GA():
             self.mut_pro = mut_pro
 
 ######################################### 3 基本蛙跳算法##################################################################
-from math import *
-import random as rand
-import numpy as np
-from numpy.core.fromnumeric import argmax, argmin
+
 class Frog():
     def __init__(self,x) -> None:
         self.x = x
@@ -654,7 +651,7 @@ class Frog():
             -------
             y : float/int --> 位置(解)对应的评价值。
         '''
-        return x + 10*sin(5*x) + 7*cos(4*x);
+        return x + 10*mh.sin(5*x) + 7*mh.cos(4*x);
 
 
 class Shuffled_Frog_Leaping_Algorithm():
